@@ -358,7 +358,7 @@ def p(level,fmt,*info):#输出信息
         if swid==0 or logid==0:return   #事务id或者调用id为0则返回
         insertSql = "insert into sw_detaillog (dispathno,swid,no,log_time,log_msg,log_level) values (:dispathno,:swid,:no,sysdate,:log_msg,:log_level)"
         cur = swdb.conn.cursor()
-        cur.setinputsizes(log_msg=swdb.BLOB)
+        cur.setinputsizes(log_msg=swdb.dbdriver.BLOB)
         cur.execute(insertSql, {'dispathno':logid,'swid':swid,'no':logno,'log_msg':sinfo.encode("gbk"),'log_level':level})
         logno = logno + 1
         swdb.conn.commit()
