@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 # -*- coding: utf8 -*-
 
-__all__=["可靠邮件","普通邮件"]
+__all__=["可靠邮件","普通邮件","create_html_table"]
 
 from email import encoders
 import smtplib,configparser,os
@@ -12,10 +12,10 @@ import libsw3 as sw3
 sw3.__all__=sw3.__all__ + __all__
 
 class 普通邮件(object):   #直接发送，如果发送失败，可能导致程序崩溃或者邮件发送失败
-    def __init__(self,发送者,标题,正文,接收,抄送=[],暗送=[]):
+    def __init__(self,发送者,标题,正文,接收,抄送=[],暗送=[],邮件类型="plain"):
         self.参数=[发送者,标题,正文,接收,抄送,暗送]
         self.msg=MIMEMultipart()
-        self.msg.attach(MIMEText(正文, 'plain', 'gbk'))
+        self.msg.attach(MIMEText(正文, 邮件类型, 'gbk'))
         self.msg['Subject'] = 标题
         self.msg['From'] = "%s@mail.rtfund.com" %(发送者)
         self.dz=[]
@@ -50,13 +50,7 @@ class 可靠邮件(object):   #把数据保存在本地硬盘，使用另一个
     def __init__(self,发送者,标题,正文,接收,抄送=[],暗送=[]):
         self.参数=[发送者,标题,正文,接收,抄送,暗送]
     
-def create_html_table(headlist,keylist,datalist):
-    '''
-		生成table样式的html内容。参数信息如下：
-		headlist		- 字符list,用于表头显示的文本
-		keylist			- 字符list,key顺序与thead保持一致
-		datalist		- 对象list,用于存储表格中显示的数据
-	'''
+def create_html_table(headlist,keylist,datalist):   #生成table样式的html内容。参数：表头文本，字段显示顺序，要显示的数据（每一行是一个字典）
     _html, _head, _trs = ("", "<tr>", "")
     if len(headlist)==len(keylist):
         # head
